pub enum PubSubError {
InvalidArgument(String),
PublishError(UStatus),
}Expand description
An error indicating a problem with publishing a message to a topic.
Variants
InvalidArgument(String)
Indicates that the given message cannot be sent because it is not a valid Publish message.
PublishError(UStatus)
Indicates an unspecific error that occurred at the Transport Layer while trying to publish a message.